import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

//Data is declared from the dataset and adjusting lengths of the plot. 
const svg = select('svg');
const height = +(svg.attr('height'));
const width = +(svg.attr('width'));
const render = data =>{
  const xValue = d =>d.timestamp;
  const xAxisLabel = 'time stamp'
  const yValue = d=> d.bitcoin;
  const yAxisLabel = 'bitcoin rates'
  const circleRadius = 6;
  const title = 'Bitcoin rate flow';
  const margin = {top: 55, rigth: 40, bottom: 70, left: 100}
  const innerWidth = width -margin.left - margin.rigth;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data,xValue))
  	.range([0,innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([innerHeight,0])
  	.nice();
  
	const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g')
                .call(yAxis)
  yAxisG.selectAll('.domain')
        	.remove();
  
  yAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('x',-innerHeight/2)
  	.attr('y',-50)
  	.attr('fill','red')
  	.attr('text-anchor','middle')
  	.attr('transform',`rotate(-90)`)
    .text(yAxisLabel);
  
 	const xAxisG = g.append('g').call(xAxis)
                  .attr('transform',`translate(0,${innerHeight})`)
  xAxisG.select('.domain').remove();
  
//Declaring the X-aix values and length.
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('x',innerWidth/2)
  	.attr('y',70)
    .attr('fill','red')
    .text(xAxisLabel)
  
//Using the line generator for line chart
  const lineGenerator = line()
  	.x(d =>xScale(xValue(d)))
  	.y(d=>yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('stroke','red')
  	.attr('d', lineGenerator(data))
  
  g.append('text')
  	.attr('class','title')
    .attr('x',innerWidth/2)
  	.attr('y',-10)
  	.attr('text-anchor','middle')
  	.text(title);
};
// Providing the Dataset URL
csv('https://gist.githubusercontent.com/suchitra2602/9ca8f4d32b6a903fa2f80dcfbed37ed4/raw/3b876e7c6081399e79f9b453e63618ceb3edb7ce/bitcoin.csv').then(data =>{
    data.forEach(d =>{
      d.bitcoin= +d.bitcoin;
			d.timestamp = new Date(d.timestamp);
    });
    render(data);
});
